You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@apr.apache.org by jo...@apache.org on 2005/01/13 12:17:43 UTC

svn commit: r125063 - /apr/apr/trunk/build/buildcheck.sh

Author: jorton
Date: Thu Jan 13 03:17:38 2005
New Revision: 125063

URL: http://svn.apache.org/viewcvs?view=rev&rev=125063
Log:
* build/buildcheck.sh: Require autoconf 2.50 or later.

Modified:
   apr/apr/trunk/build/buildcheck.sh

Modified: apr/apr/trunk/build/buildcheck.sh
Url: http://svn.apache.org/viewcvs/apr/apr/trunk/build/buildcheck.sh?view=diff&rev=125063&p1=apr/apr/trunk/build/buildcheck.sh&r1=125062&p2=apr/apr/trunk/build/buildcheck.sh&r2=125063
==============================================================================
--- apr/apr/trunk/build/buildcheck.sh	(original)
+++ apr/apr/trunk/build/buildcheck.sh	Thu Jan 13 03:17:38 2005
@@ -14,18 +14,18 @@
 echo "buildconf: python version $py_version (ok)"
 fi
 
 # autoconf 2.13 or newer
 ac_version=`${AUTOCONF:-autoconf} --version 2>/dev/null|sed -e 's/^[^0-9]*//;s/[a-z]* *$//;q'`
 if test -z "$ac_version"; then
 echo "buildconf: autoconf not found."
-echo "           You need autoconf version 2.13 or newer installed"
+echo "           You need autoconf version 2.50 or newer installed"
 echo "           to build Apache from CVS."
 exit 1
 fi
 IFS=.; set $ac_version; IFS=' '
-if test "$1" = "2" -a "$2" -lt "13" || test "$1" -lt "2"; then
+if test "$1" = "2" -a "$2" -lt "50" || test "$1" -lt "2"; then
 echo "buildconf: autoconf version $ac_version found."
-echo "           You need autoconf version 2.13 or newer installed"
+echo "           You need autoconf version 2.50 or newer installed"
 echo "           to build Apache from CVS."
 exit 1
 else
@@ -14,18 +14,18 @@
 fi
 
-# autoconf 2.13 or newer
+# autoconf 2.50 or newer
 ac_version=`${AUTOCONF:-autoconf} --version 2>/dev/null|sed -e 's/^[^0-9]*//;s/[a-z]* *$//;q'`
 if test -z "$ac_version"; then